firewall {
    all-ping enable
    broadcast-ping disable
    ipv6-receive-redirects disable
    ipv6-src-route disable
    ip-src-route disable
    log-martians enable
    name WAN_IN {
        default-action drop
        description "packets from Internet to the LAN"
        rule 1 {
            action accept
            description "allow established session to the LAN"
            log disable
            protocol all
            state {
                established enable
                invalid disable
                new disable
                related enable
            }
        }
        rule 3 {
            action drop
            description "drop invalid state"
            log disable
            protocol all
            state {
                established disable
                invalid enable
                new disable
                related disable
            }
        }
    }
    name WAN_LOCAL {
        default-action drop
        description "packets from Internet to the router"
        rule 1 {
            action accept
            description "allow established session to the router"
            log disable
            protocol all
            state {
                established enable
                invalid disable
                new disable
                related enable
            }
        }
        rule 2 {
            action drop
            description "drop invalid state"
            log disable
            protocol all
            state {
                established disable
                invalid enable
                new disable
                related disable
            }
        }
        rule 3 {
            action accept
            description "allow ping"
            log disable
            protocol icmp
        }
    }
    receive-redirects disable
    send-redirects enable
    source-validation disable
    syn-cookies enable
}
interfaces {
    ethernet eth0 {
        address 192.168.1.1/24
        description LAN
        duplex auto
        firewall {
            in {
            }
            local {
            }
            out {
            }
        }
        speed auto
    }
    ethernet eth1 {
        description WAN
        duplex auto
        firewall {
            in {
            }
            local {
            }
        }
        speed auto
        vif 4 {
            address dhcp
            description WAN-IPTV
            firewall {
                in {
                }
                local {
                }
            }
            mac 10:7B:EF:XX:XX:XX
        }
        vif 34 {
            address dhcp
            description WAN-INTERNET
            dhcp-options {
                default-route update
                default-route-distance 50
                name-server update
            }
            firewall {
                in {
                    name WAN_IN
                }
                local {
                    name WAN_LOCAL
                }
            }
            mac 10:7B:EF:XX:XX:XX
        }
    }
    ethernet eth2 {
        disable
        duplex auto
        firewall {
            in {
            }
            local {
            }
            out {
            }
        }
        speed auto
    }
    loopback lo {
    }
}
protocols {
    igmp-proxy {
        interface eth0 {
            role downstream
            threshold 1
            whitelist 239.0.0.0/16
            whitelist 225.0.71.0/24
            whitelist 224.0.0.0/16
        }
        interface eth1 {
            role disabled
            threshold 1
        }
        interface eth1.4 {
            alt-subnet 0.0.0.0/0
            role upstream
            threshold 1
        }
        interface eth1.34 {
            role disabled
            threshold 1
        }
        interface eth2 {
            role disabled
            threshold 1
        }
    }
    static {
        route 185.6.48.0/26 {
            next-hop 10.10.28.1 {
            }
        }
    }
}
service {
    dhcp-server {
        disabled false
        hostfile-update disable
        shared-network-name LAN {
            authoritative disable
            subnet 192.168.1.0/24 {
                default-router 192.168.1.1
                dns-server 8.8.8.8
                dns-server 8.8.4.4
                lease 86400
                start 192.168.1.100 {
                    stop 192.168.1.255
                }
            }
        }
    }
    gui {
        http-port 80
        https-port 443
        older-ciphers enable
    }
    nat {
        rule 2 {
            description ipv-srtp-abox1
            disable
            inbound-interface eth1.4
            inside-address {
                address 192.168.1.20
                port 555-65000
            }
            log disable
            protocol udp
            source {
                address 185.6.48.0/26
            }
            type destination
        }
        rule 5000 {
            description masquerade
            log disable
            outbound-interface eth1.34
            protocol all
            type masquerade
        }
        rule 5001 {
            description iptv1
            destination {
            }
            log disable
            outbound-interface eth1.4
            protocol all
            type masquerade
        }
    }
    ssh {
        port 22
        protocol-version v2
    }
    ubnt-discover {
        disable
    }
    upnp2 {
        listen-on eth0
        nat-pmp disable
        secure-mode disable
        wan eth1.34
    }
}
system {
    host-name ubnt
    login {
        user ubnt {
            authentication {
                encrypted-password $6$q9QOnwO7vWvY$qskInXyJHBwAjSRO.22nyTa/ZI8I777AdCxl8E.xmYFpH1ga77hQSwfSNhyS045xT3Ln9aHGBSvJLAIV8j0j9/
                plaintext-password ""
            }
            full-name ""
            level admin
        }
    }
    ntp {
        server 0.ubnt.pool.ntp.org {
        }
        server 1.ubnt.pool.ntp.org {
        }
        server 2.ubnt.pool.ntp.org {
        }
        server 3.ubnt.pool.ntp.org {
        }
    }
    offload {
        hwnat disable
        ipsec enable
        ipv4 {
            forwarding enable
            vlan enable
        }
        ipv6 {
            forwarding disable
        }
    }
    package {
        repository wheezy {
            components "main contrib non-free"
            distribution wheezy
            password ""
            url http://http.us.debian.org/debian
            username ""
        }
        repository wheezy-security {
            components main
            distribution wheezy/updates
            password ""
            url http://security.debian.org
            username ""
        }
    }
    syslog {
        global {
            facility all {
                level notice
            }
            facility protocols {
                level debug
            }
        }
    }
    time-zone Europe/Amsterdam
    traffic-analysis {
        dpi disable
        export disable
    }
}


/* Warning: Do not remove the following line. */
/* === vyatta-config-version: "config-management@1:conntrack@1:cron@1:dhcp-relay@1:dhcp-server@4:firewall@5:ipsec@4:nat@3:qos@1:quagga@2:system@4:ubnt-pptp@1:ubnt-util@1:vrrp@1:webgui@1:webproxy@1:zone-policy@1" === */
/* Release version: v1.8.5.4884695.160608.1057 */
